EventController class

Controlador principal de eventos para el SDK de Obsly

Constructors

EventController({required ObslyStorage storage, required EventSender sender, required IdManager idManager, bool? enableDebugTools})

Properties

hashCode int
The hash code for this object.
no setterinherited
idManager IdManager
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender EventSender
final
storage ObslyStorage
final

Methods

dispose() → void
Releases controller resources
flush({bool force = false}) Future<void>
Fuerza el envío de todos los eventos pendientes Si force es true, envía eventos incluso si el modo debug está habilitado
forceFlush() Future<void>
Fuerza el envío manual de eventos (usado por las debug tools) Este método siempre envía eventos, independientemente del modo debug
getRateLimitStatus() Map<String, Map<String, dynamic>>
Get rate limiting status for debugging
isSendActive() bool
Obtiene el estado del envío de eventos
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setSendActive(bool active) → void
Habilita o deshabilita el envío de eventos al servidor
start() Future<void>
Inicia el controlador de eventos
toString() String
A string representation of this object.
inherited
trackEvent(dynamic event) Future<void>
Trackea un evento (compatible con ObslyEvent y Map)
trackEventPriority(dynamic event) Future<void>
Trackea un evento con prioridad alta (crashes, errores críticos) Los eventos prioritarios bypasean el rate limiting para asegurar que se procesen
updateRateLimiters() → void
Update rate limiters with new configuration (useful when config changes)

Operators

operator ==(Object other) bool
The equality operator.
inherited