HTTPResponseMetadata class

HTTP response metadata for enrichment and analysis

Constructors

HTTPResponseMetadata({required int statusCode, Map<String, String> headers = const {}, String? body, required Duration duration})

Properties

body String?
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

getSafeResponseBody() String?
Extract safe response body
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited