ObslyEventExtra class
Estructura extra del evento
Constructors
Properties
- app → App?
-
final
- category → String?
-
final
- device → Device?
-
final
- error → Error?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifeCycle → LifeCycle?
-
final
- metric → Metric?
-
final
- performanceBlock → Performance?
-
final
- request → Request?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- ui → Ui?
-
final
- user → User?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited