UIEventBase class

Lightweight UI event - only essential data Hub will enrich with device info, session data, etc.

Inheritance

Constructors

UIEventBase({required String actionType, String? targetWidget, Offset? position, String? route, Map<String, dynamic> widgetInfo = const {}, String? screenshot, DateTime? timestamp})

Properties

actionType String
final
data Map<String, dynamic>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
no setteroverride
position Offset?
final
route String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshot String?
final
targetWidget String?
final
timestamp DateTime
no setteroverride
type EventType
no setteroverride
widgetInfo Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited