BankingAppBenchmarkSuite class

📋 SUITE PREDEFINIDA PARA BANKING APP

Inheritance

Constructors

BankingAppBenchmarkSuite()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tests → List<BenchmarkTest>
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() → Future<BenchmarkSuiteResult>
Ejecuta todos los benchmarks de la suite
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited