ObslyTools class
Modelo para manejar obsly_tools que viene en la RemoteConfig
Constructors
- ObslyTools({String? textsUrl, String? rulesUrl})
-
const
-
ObslyTools.fromMap(Map<
String, dynamic> map) -
Crea desde Map (para deserialización)
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRulesUrl → bool
-
Verifica si tiene URL de rules válida
no setter
- hasTextsUrl → bool
-
Verifica si tiene URL de texts válida
no setter
- hasValidUrls → bool
-
Verifica si tiene URLs válidas
no setter
- rulesUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textsUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Convierte a Map para serialización
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited